#!/usr/bin/env python
##################################################
# Gnuradio Python Flow Graph
# Title: Top Block
# Generated: Tue Dec 15 12:26:16 2015
##################################################

from gnuradio import eng_notation
from gnuradio import gr
from gnuradio import wxgui
from gnuradio.eng_option import eng_option
from gnuradio.fft import window
from gnuradio.filter import firdes
from gnuradio.wxgui import fftsink2
from gnuradio.wxgui import forms
from gnuradio.wxgui import waterfallsink2
from grc_gnuradio import wxgui as grc_wxgui
from optparse import OptionParser
import elad
import wx

class top_block(grc_wxgui.top_block_gui):

    def __init__(self):
        grc_wxgui.top_block_gui.__init__(self, title="Top Block")
        _icon_path = "/usr/share/icons/hicolor/32x32/apps/gnuradio-grc.png"
        self.SetIcon(wx.Icon(_icon_path, wx.BITMAP_TYPE_ANY))

        ##################################################
        # Variables
        ##################################################
        self.samp_rate = samp_rate = 192000
        self.freq = freq = 14200000
        self.fil = fil = 1
        self.att = att = 0

        ##################################################
        # Blocks
        ##################################################
        _freq_sizer = wx.BoxSizer(wx.VERTICAL)
        self._freq_text_box = forms.text_box(
        	parent=self.GetWin(),
        	sizer=_freq_sizer,
        	value=self.freq,
        	callback=self.set_freq,
        	label="frequency",
        	converter=forms.int_converter(),
        	proportion=0,
        )
        self._freq_slider = forms.slider(
        	parent=self.GetWin(),
        	sizer=_freq_sizer,
        	value=self.freq,
        	callback=self.set_freq,
        	minimum=14000000,
        	maximum=14350000,
        	num_steps=1000,
        	style=wx.SL_HORIZONTAL,
        	cast=int,
        	proportion=1,
        )
        self.Add(_freq_sizer)
        self._fil_chooser = forms.radio_buttons(
        	parent=self.GetWin(),
        	value=self.fil,
        	callback=self.set_fil,
        	label="Input Attenuator",
        	choices=[0,1],
        	labels=["Bypass","Normal"],
        	style=wx.RA_HORIZONTAL,
        )
        self.Add(self._fil_chooser)
        self._att_chooser = forms.radio_buttons(
        	parent=self.GetWin(),
        	value=self.att,
        	callback=self.set_att,
        	label="Input Attenuator",
        	choices=[0,1],
        	labels=["OFF","ATTENUATE"],
        	style=wx.RA_HORIZONTAL,
        )
        self.Add(self._att_chooser)
        self.wxgui_waterfallsink2_0 = waterfallsink2.waterfall_sink_c(
        	self.GetWin(),
        	baseband_freq=0,
        	dynamic_range=100,
        	ref_level=0,
        	ref_scale=2.0,
        	sample_rate=samp_rate,
        	fft_size=512,
        	fft_rate=15,
        	average=False,
        	avg_alpha=None,
        	title="Waterfall Plot",
        )
        self.Add(self.wxgui_waterfallsink2_0.win)
        self.wxgui_fftsink2_0 = fftsink2.fft_sink_c(
        	self.GetWin(),
        	baseband_freq=0,
        	y_per_div=10,
        	y_divs=10,
        	ref_level=0,
        	ref_scale=2.0,
        	sample_rate=samp_rate,
        	fft_size=1024,
        	fft_rate=15,
        	average=False,
        	avg_alpha=None,
        	title="FFT Plot",
        	peak_hold=False,
        )
        self.Add(self.wxgui_fftsink2_0.win)
        self.elad_fdms2_source_c_0 = elad.fdms2_source_c(LOfreq=freq,
        	filter=fil,
        	atten=att)
          

        ##################################################
        # Connections
        ##################################################
        self.connect((self.elad_fdms2_source_c_0, 0), (self.wxgui_fftsink2_0, 0))
        self.connect((self.elad_fdms2_source_c_0, 0), (self.wxgui_waterfallsink2_0, 0))



    def get_samp_rate(self):
        return self.samp_rate

    def set_samp_rate(self, samp_rate):
        self.samp_rate = samp_rate
        self.wxgui_fftsink2_0.set_sample_rate(self.samp_rate)
        self.wxgui_waterfallsink2_0.set_sample_rate(self.samp_rate)

    def get_freq(self):
        return self.freq

    def set_freq(self, freq):
        self.freq = freq
        self.elad_fdms2_source_c_0.set_FREQ(self.freq)
        self.elad_fdms2_source_c_0.set_filter(self.freq,self.fil,self.att)
        self.elad_fdms2_source_c_0.set_atten(self.freq,self.fil,self.att)
        self._freq_slider.set_value(self.freq)
        self._freq_text_box.set_value(self.freq)

    def get_fil(self):
        return self.fil

    def set_fil(self, fil):
        self.fil = fil
        self.elad_fdms2_source_c_0.set_filter(self.freq,self.fil,self.att)
        self.elad_fdms2_source_c_0.set_atten(self.freq,self.fil,self.att)
        self._fil_chooser.set_value(self.fil)

    def get_att(self):
        return self.att

    def set_att(self, att):
        self.att = att
        self.elad_fdms2_source_c_0.set_filter(self.freq,self.fil,self.att)
        self.elad_fdms2_source_c_0.set_atten(self.freq,self.fil,self.att)
        self._att_chooser.set_value(self.att)

if __name__ == '__main__':
    import ctypes
    import sys
    if sys.platform.startswith('linux'):
        try:
            x11 = ctypes.cdll.LoadLibrary('libX11.so')
            x11.XInitThreads()
        except:
            print "Warning: failed to XInitThreads()"
    parser = OptionParser(option_class=eng_option, usage="%prog: [options]")
    (options, args) = parser.parse_args()
    tb = top_block()
    tb.Start(True)
    tb.Wait()
